# Relax Front-End Integration Module (FEIM)

Relax’s new front-end integration module (FEIM) handles all the front-end communication such as balance updates, opening/closing of menus, and error codes. FEIM is a TypeScript library, available as an npm module.

FEIM includes the same functionality for operators as the Post Message API so it is recommended to remove other Post Message API functionality when FEIM is implemented. FEIM will enable easier custom integrations in the future due to a new adaption layer, which our Post Message API cannot easily support.

### Installation
```bash
npm i @rlx/feim
```
or
```html
<!-- the newest version of a major release (backwards compatible) -->
<script src="/casino/relaxlibs/feim/1/rlxfeim.min.js"></script>
<!-- a specific version - you can replace '1.10.0' with any released version -->
<script src="/casino/relaxlibs/feim/1.10.0/rlxfeim.min.js"></script>
```
With the latter method FEIM will be available as the global `FEIM`, e.g. `FEIM.send.roundStarted()`.

The following examples will assume that the npm method is used.

### Initial configuration
[[configure]] can be called multiple times as the relevant data comes available, or you can send all the data at once, as below.

Relax game server users must provide 'clientConfig' and 'loginResponse'.
Others must provide 'p2pConfig', which currently only contains the currency code.

See [[IModuleConfig]] for more detailed descriptions on what these parameters do or require.

``` javascript
import { configure } from "@rlx/feim";

configure({
  // The received response from /getclientconfig/, or an object adhering to its format
  // (Relax game server users only):
  clientConfig: clientconfigResponse,
  // The casino login response, or an object adhering to its format
  // (Relax game server users only):
  loginResponse: casinoLoginResponse,

  // When clientConfig and loginResponse cannot be provided
  // (only when not using the Relax game server):
  p2pConfig: {currency: "EUR"},

  /* If set to true, FEIM will handle the responsibilities of RgPostMessageAPI library.
  If true, RgPostMessageAPI library or any equivalent/duplicate integration must be
  removed from the game. */
  handleRgPostMessageAPI: true,

  /* Some jurisdictions require that the game needs to wait for a user confirmation when
  a bonus game is reached. Set this to false if the game handles it internally. */
  handleFeaturePause: true,

  // Optional, see showError:
  showErrorMessageCallback: MY_GAME.showInGameErrorMessage,
});
```
If you can only provide p2pConfig, you must handle [[onRealityCheckChoiceRequired]] separately.

### Sending messages to the operator
**This list of examples is not exhaustive; all the supported events are listed here: {@link "send"}**
```
import { send } from "@rlx/feim";
```
***Initial settings:***

Initial sound setting should be sent before gameLoadStarted.
``` javascript
send.updateSettings({sounds: false});
```
***Game load:***
``` javascript
send.gameLoadStarted();
send.gameLoadProgress(0);
send.gameLoadProgress(50);
send.gameLoadProgress(100);
send.gameLoadCompleted();
```
***Game Round:***

When a round animation starts, call [[roundStarted]]:
``` javascript
send.roundStarted();
```
When a bonus round animation is about to start animating, call [[featureStarted]]:
``` javascript
send.featureStarted();
```
When a bonus round animation ends, call [[featureFinished]]:
``` javascript
send.featureFinished();
```
The easiest way to keep the balance in sync is to call [[balanceUpdate]] every time the game balance field is updated:
``` javascript
send.balanceUpdate(1234);
```
After the round win is displayed, the final win amount needs to be reported.
A win update needs to be sent even if the win is 0.
You can simply send the win amount with [[roundFinished]], or you can send a [[winUpdate]] before it:
``` javascript
send.winUpdate({win: 100});
```
Note: If you have a count up animation/tween in your win or balance field, do not dispatch an update for each tick - only send the final value.

When the round animation has ended, call [[roundFinished]]:
``` javascript
send.roundFinished({playResponse: lastPlayResponse, finishedResponse: gamefinishedEndpointResponse});
```
'playResponse' should be the final /play response (where 'ended' is true) if using Relax game server, otherwise see [[IRoundFinishedData]] for details.

finishedResponse contains additional round resolution information. It is required if `disableSpinUntilGameFinished` is true in /getclientconfig, otherwise optional. Simply give it the /gamefinished endpoint response if using Relax game server.

***Autoplay***

When an autoplay session starts, call [[autoPlayStarted]]:
``` javascript
send.autoPlayStarted();
```
When an autoplay session ends, call [[autoPlayFinished]]:
``` javascript
send.autoPlayFinished();
```

***User Interface triggers***

When bet is changed, call [[betUpdate]]:
``` javascript
send.betUpdate(10);
```
If your game has a close button (like a home button on mobile), tell the operator to close the game with [[exitGame]]:
``` javascript
if (!send.exitGame()) {
    // There is a configuration problem, and game exit is not possible.
    // This should not happen in production, and can be considered an error.
} else {
    // Nothing needs to be done; the operator will close the game frame,
    // or FEIM will navigate to homeurl or go back in browser history.
}
```
_exitGame_ will always return true if the environment is configured correctly, so handling its return value is not required.

### Listening to operator window events
**This list of examples is not exhaustive; all the supported events are listed here: {@link "on"}**
```
import { on } from "@rlx/feim";
```
[[refreshBalance]] is triggered if the operator requests a balance update; the player possibly made a deposit.
Make sure that the refreshed balance is sent back to the operator with [[balanceUpdate]].
``` javascript
on.refreshBalance(MY_GAME.refreshBalanceFromCasinoServer);
```
Sometimes the game must freeze (prevent playing and block user interaction).
In these situations FEIM triggers a [[freeze]] event.
``` javascript
on.freeze(MY_GAME.freeze);
on.unfreeze(MY_GAME.unfreeze);
```
[[updateSettings]] is received if some setting is changed in the operator UI, and the game needs to react to it:
``` javascript
on.updateSettings((newSetting) => {
    // Only the changed setting is in newSetting, not the entire settings state
    if (newSetting.sounds !== undefined) {
        MY_GAME.setSoundEnabled(newSetting.sounds);
    }
});
```

### Error messages
Some operators require that they handle showing all the error messages. In these situations there should be no in-game error popups.

FEIM offers some helpers for this.

If you have properly configured [[showErrorMessageCallback]] you can just call [[showError]]:
``` javascript
import { showError } from "@rlx/feim";

// casinoResponseContainingError is the response payload as it comes from Casino World
await showError(casinoResponseContainingError); // Opens an error popup in the game or in the operator window
console.log("Error message closed, continuing game");
```
When _showError_ is called, FEIM will trigger [[freeze]], show an error popup (operator side or in-game), and then call [[unfreeze]] once the popup is closed.
A proper [[showErrorMessageCallback]] must be given in FEIM [[configure]] for this to work.
_showErrorMessageCallback_ must return a Promise which is resolved when the popup is closed, otherwise _unfreeze_ will trigger immediately.

_showError_ also returns a Promise, resolved when the error popup is closed.

If you don't want to use _showError_, you can do something like this instead:
``` javascript
const remotePopupShown = send.errorMessage(errorResponse);
// send.errorMessage returns false if the operator is not showing error popups:
if (!remotePopupShown) {
    MY_GAME.showInGameErrorMessage(errorResponse);
}
```
on.[[errorMessageDisplayed]] and on.[[errorMessageDismissed]] will trigger if an operator side error message is shown/dismissed.

If you need to know if operator side error popups are enabled, use [[getConfiguration]]:
``` javascript
getConfiguration().operatorHandlesErrors
```