import { IGameSettings } from "./types";
import { IUIActionDetails } from "../interfaces/feim.interface";
/**
 * Triggered once the environment configuration is received from both the game and the operator.
 * Handshake is done and everything is set up.
 *
 * Can be useful if you need to do something with [[getConfiguration]] early on, as the values will be undefined before this.
 * Otherwise there's no need to listen to this.
 * @param callback
 */
export declare const initialized: (callback: () => void) => void;
/**
 * The operator requests a balance update.
 *
 * Request Casino World API `/getbalance/` and then use send.[[balanceUpdate]] to send back the refreshed balance.
 */
export declare const refreshBalance: (callback: () => void) => void;
/**
 * Settings have been changed in the operator front end, they need to be synchronized in game.
 *
 * The settings argument only contains the changed settings, unchanged settings are undefined:
 * ```
 * on.updateSettings((changedSettings) =>
 * {
 *   if (changedSettings.sounds !== undefined) {
 *     enableSounds(changedSettings.sounds)
 *   }
 *
 *   if (changedSettings.fastPlay !== undefined) {
 *     enableFastPlay(changedSettings.fastPlay)
 *   }
 * })
 * ```
 *
 * @param callback A function to update in-game settings to match
 */
export declare const updateSettings: (callback: (settings: IGameSettings) => void) => void;
/**
 * Paytable should be shown, hidden, or its visibility toggled (if applicable).
 *
 * If the action argument is undefined or doesn't specify the action type, toggle paytable visibility.
 *
 * If `action?.type` is for example `"show"` but the paytable is already visible, this event should do nothing.
 */
export declare const togglePaytable: (callback: (details?: IUIActionDetails | undefined) => void) => void;
/**
 * If you do not want to use [[showError]], this can be used to detect when an error message
 * popup is dismissed in the operator window.
 */
export declare const errorMessageDismissed: (callback: () => void) => void;
/**
 * An error message was displayed in the operator window.
 */
export declare const errorMessageDisplayed: (callback: () => void) => void;
/**
 * Game help should be shown, hidden, or its visibility toggled.
 *
 * If the action argument is undefined or doesn't specify the action type, toggle game help visibility.
 *
 * If `action?.type` is for example `"show"` but game help is already visible, this event should do nothing.
 */
export declare const toggleGameHelp: (callback: (action?: IUIActionDetails | undefined) => void) => void;
/**
 * The game will be closed imminently.
 *
 * The operator will handle closing the game frame; this function can be used to for example send any last second messages.
 */
export declare const exitingGame: (callback: () => void) => void;
/**
 * Pause autoplay, or stop it if pausing is not possible.
 */
export declare const pauseAutoPlay: (callback: () => void) => void;
/**
 * @hidden
 * Disable play controls so that no further gameplay is possible until on.[[unlockPlay]] is received.
 *
 * Autoplay should be paused, if active.
 */
export declare const lockPlay: (callback: () => void) => void;
/**
 * @hidden
 * Enable play controls if they were disabled by on.[[lockPlay]]
 */
export declare const unlockPlay: (callback: () => void) => void;
/**
 * When received, pause the game, prevent further game play, and block user interaction. Unfreeze when on.[[unfreeze]] is received.
 *
 * If received during an active game round, the game animation should be paused immediately instead of waiting until the end of the round,
 * as sometimes the game must be paused mid-round before a feature/bonus game starts. Reality check related freezes are automatically delayed
 * until any ongoing game round has ended.
 *
 * Any ongoing autoplay must be paused.
 */
export declare const freeze: (callback: () => void) => void;
/**
 * When received, unfreeze the game if it's been frozen by on.[[freeze]]
 */
export declare const unfreeze: (callback: () => void) => void;
