import { IErrorMessage, IFeatureData, IGameSettings, IRoundFinishedData, IRoundStartedData, IUIState, IWinnings } from "./types";
/**
 * Report that the game has started loading.
 */
export declare const gameLoadStarted: () => void;
/**
 * Send game load progress.
 * @param progress - Game loading progress, between 0 and 100
 */
export declare const gameLoadProgress: (progress: number) => void;
/**
* Report that the game has finished loading.
*/
export declare const gameLoadCompleted: () => void;
/**
 * Report that a game round has started animating.
 * @param roundStartedData - Optional data containing balance information when a round starts. Can be omitted if balance is already being sent using send.[[balanceUpdate]]
 */
export declare const roundStarted: (roundStartedData?: IRoundStartedData | undefined) => void;
/**
 * Reports that the game round animations have completed, and final balance is shown.
 * @param roundFinishedData Game status after round end.
 */
export declare const roundFinished: (roundFinishedData?: IRoundFinishedData | undefined) => void;
/**
 * Report that a feature (bonus game) is a starting.
 * In some jurisdictions the game will be paused with [[freeze]] as a response, and continued once the player has confirmed it.
 * (see [[handleFeaturePause]])
 * @param featureData Feature details, such as type. Optional, can be used to fine tune the response to this event.
 */
export declare const featureStarted: (featureData?: IFeatureData | undefined) => void;
/**
 * Report that a feature (bonus game) has finished.
 * @param featureData Feature details, such as type. Optional, can be used to fine tune the response to this event.
 */
export declare const featureFinished: (featureData?: IFeatureData | undefined) => void;
/**
 * Report that an autoplay session has started.
 */
export declare const autoPlayStarted: () => void;
/**
 * Report that an autoplay session has ended.
 */
export declare const autoPlayFinished: () => void;
/**
 * Sends a balance update to operator window.
 *
 * send.[[roundStarted]] and send.[[roundFinished]] will automatically send this if their balance fields are valid (not negative).
 *
 * on.[[refreshBalance]] needs to be answered with this.
 *
 * @param balance - New balance, in cents
 */
export declare const balanceUpdate: (balance: number) => void;
/**
 * Report a stake/bet amount change.
 * @param bet - The new bet amount, in cents
 */
export declare const betUpdate: (bet: number) => void;
/**
 * Report a win.
 *
 * `send.roundFinished` will send this automatically if it has a valid winnings field.
 *
 * A win update must be sent for every played round, even if the win is 0.
 *
 * @param win - Win amount data
 */
export declare const winUpdate: (win?: IWinnings | undefined) => void;
/**
 * Report a setting change.
 *
 * @param settings - An object containing one ore more changed settings
 */
export declare const updateSettings: (settings: IGameSettings) => void;
/**
 * Send an error message for the operator to show.
 *
 * If you do not want to use [[showError]], you can use this to send the error message directly.
 *
 * Use on.[[errorMessageDismissed]] to detect when the popup is closed in the operator window.
 *
 * Use on.[[errorMessageDisplayed]] if you need to know if a popup was displayed in the operator window.
 *
 * [[operatorHandlesErrors]] in [[getConfiguration]] return data is true if the environment is using remote error messages.
 *
 * @param message - The error message, in the format it is received from the Casino server
 *
 * @returns False if the operator is not handling error popups, and they should be shown in game ([[getConfiguration]] returns [[operatorHandlesErrors]] as false).
 */
export declare const errorMessage: (message: IErrorMessage) => boolean;
/**
 * Navigates the game window to a new page.
 *
 * Also handles the `action:` prefix.
 *
 * Note: [[exitGame]] will navigate to `&homeurl` automatically, so it's possible you never need to use this function directly.
 *
 * @param target Navigate target - url or user action
 * @returns true if the parameter was defined and not empty
 */
export declare const navigate: (target?: string | undefined) => boolean;
/**
 * Request game exit. Covers all game exit situations: will notify the operator, redirect the game window to `&homeurl`, or move back in browser history if neither
 * is applicable. Also handles the 'buttonEventsIframe' setting of client config.
 *
 * Called for example when the home button is clicked on mobile, or when the game is closed via reality check.
 *
 * @returns True if succesful. False if there's a configuration error, and closing the game is not possible.
 */
export declare const exitGame: () => boolean;
/**
 * Show history. Will notify the operator or open a new tab to RC history URL.
 *
 * Must be called directly from a user interaction handler (e.g. a click event), otherwise the popup might get blocked.
 */
export declare const showHistory: () => void;
/**
 * @hidden
 * Go to a game, if the operator supports it. This game will be closed if successful.
 *
 * Using this is optional.
 */
export declare const goToGame: (gameRef: string) => boolean;
/**
 * Open a quick deposit, if the operator supports it.
 *
 * Using this is optional. Can be sent for example when the in-game out of funds error message is closed.
 *
 * The operator is expected to dispatch [[refreshBalance]] if a deposit is made.
 *
 * If the operator does not support this, nothing will happen.
 */
export declare const openQuickDeposit: () => void;
/**
 * Report a change in user interface.
 *
 * e.g. `send.reportUIState({splashScreenVisible: true})`
 *
 * Using this is optional.
 */
export declare const reportUIState: (state: IUIState) => void;
