import { IErrorMessage } from "../interfaces/feim.interface";
import { LogLevel } from "../utils/log";
/**
 * This module contains the interfaces available to the game
 */
/**
 * Configuration defined by the game
 * @public
 */
export interface IModuleConfig {
    /**
     * Game config from the Client Config API `/games/getclientconfig/`, if using the Relax game server.
     */
    readonly clientConfig?: IClientConfig;
    /**
     * Login response as it comes from the Relax game server.
     */
    readonly loginResponse?: ILoginResponse;
    /**
     * Must be set if `loginResponse` and `clientConfig` cannot be given (if not using the Relax game server).
     * In this case see also [[onRealityCheckChoiceRequired]]
     */
    readonly p2pConfig?: IP2PConfig;
    /**
     * Function used to handle in-game errors if remote error popups are not enabled.
     * If given to module, the game can always just use `showError` and the module will handle
     * showing the popup, either in the game or in the operator window.
     */
    readonly showErrorMessageCallback?: (message: IErrorMessage) => Promise<void>;
    /**
     * What messages to log to console
     */
    readonly logLevel?: LogLevel;
    /**
     * Handle Rg PostMessage API and legacy RC API. Default is false.
     *
     * Leave as false if these are handled by the game, otherwise must be set to true.
     */
    readonly handleRgPostMessageAPI?: boolean;
    /**
     * If true, FEIM will handle pausing and notifying the user when a feature (bonus game) starts and ends.
     * This is a requirement in some jurisdictions.
     *
     * For this to work, the game must have support for pausing/continuing the game mid-round when [[freeze]]
     * and [[unfreeze]] are received, and the game must dispatch [[featureStarted]] and [[featureFinished]]
     * when a feature or a bonus game starts and ends.
     *
     * Leave as undefined if the game handles this internally.
     */
    readonly handleFeaturePause?: boolean;
}
/**
 * Combined configuration defined by the game and the operator environment
 */
export interface IApiConfig extends IModuleConfig {
    /**
     * If true, the error messages are shown in the operator window.
     *
     * Undefined if handshake is not yet complete.
     */
    operatorHandlesErrors?: boolean;
    /**
     * If true, the operator handles game exit, so any default behavior in game should be disabled.
     *
     * Undefined if handshake is not yet complete.
     */
    operatorHandlesGameExit?: boolean;
}
export * from "../interfaces/feim.interface";
export { IRealityCheckInput } from "../interfaces/theos.interface";
export interface IP2PConfig {
    readonly currency: string;
    readonly targetOrigin?: string;
    readonly specialSessionConfig?: unknown;
}
export interface IClientConfig {
    readonly [x: string]: boolean | string | number | number[] | undefined;
    readonly gameServerApi: string;
    readonly buttonEventsIframe?: boolean;
    readonly targetOrigin?: string;
}
export interface ILoginResponse {
    readonly [x: string]: unknown;
    readonly sid: string;
    readonly stats: {
        readonly currency: string;
    };
    readonly specialSessionConfig?: unknown;
}
