/**
 * State after the round has started
 */
export interface IRoundStartedData {
    /**
     * Remaining real balance after starting the round, before any winnings.
     *
     * To avoid double sending, leave empty if you are sending [[balanceUpdate]] elsewhere when a round starts.
     */
    readonly balance?: number;
}
/**
 * State after the round has ended
 */
export interface IRoundFinishedData {
    /**
     * Final balance after the round, including any winnings.
     * Will be ignored if undefined or negative, otherwise will automatically send a [[balanceUpdate]].
     *
     * To avoid double sending, leave empty if you are sending [[balanceUpdate]] elsewhere when a round ends.
     */
    readonly balance?: number;
    /**
     * Win data.
     */
    readonly win?: IWinnings;
    /**
     * Bet amount.
     */
    readonly bet?: number;
    /**
     * Details of the animated round.
     * Just pass the play response if using Relax game server.
     *
     * If building the data manually, _roundType_ should be 'normal' if the wager in this round came from the player's balance (wasn't a free round etc.),
     * and therefore affected the player's bet/win balance. Other round types are: 'demo', 'freerounds', 'featurefreerounds'
     */
    readonly playResponse?: {
        readonly [index: string]: unknown;
        readonly roundType: string;
    };
    /**
     * Additional round resolution data.
     *
     * Use /gamefinished endpoint response if using Relax game server.
     * This is required if `disableSpinUntilGameFinished` is true in /getclientconfig, otherwise optional.
     */
    readonly finishedResponse?: {
        readonly [key: string]: unknown;
        readonly cashierstatus?: Record<string, unknown>;
    };
}
export interface IWinnings {
    /**
     * Report a win.
     *
     * Ignored if negative
     */
    readonly win: number;
    /**
     * Report a jackpot win.
     *
     * Ignored if negative
     */
    readonly jackpotWin?: number;
}
/**
 * Contains game settings that should be kept in sync with the operator
 *
 * Usually only contains the changed setting, not the entire settings state.
 */
export interface IGameSettings {
    /**
     * Sounds enabled/disabled
     */
    readonly sounds?: boolean;
    /**
     * Fast play enabled/disabled
     */
    readonly fastPlay?: boolean;
}
export interface IErrorMessage {
    readonly errorCode: number;
    readonly errorMessage?: string;
    readonly message?: string;
    /**
     * Custom error data (errorDetails)
     */
    readonly errorDetails?: {
        readonly errorCode?: number | string;
        readonly errorMessage?: string;
        readonly errorParameters?: object;
        readonly buttontext?: string;
        readonly message?: string;
        readonly title?: string;
    };
}
/**
 * Feature details
 */
export interface IFeatureData {
    readonly type: string;
    readonly props?: unknown;
}
/**
 * User interface action details
 */
export interface IUIActionDetails {
    readonly type: "show" | "hide" | "toggle";
}
/**
 * An object containing UI state changes (not the entire UI state).
 */
export interface IUIState {
    readonly [key: string]: unknown;
    /**
     * The startup splash screen containing game description/mechanics is shown or closed. Not applicable to all games.
     */
    readonly splashScreenVisible?: boolean;
}
